[node-patches] Change in ovirt-node[master]: tests: Add sizes page to mi_basic

fabiand at fedoraproject.org fabiand at fedoraproject.org
Wed Oct 17 09:37:32 UTC 2012


Fabian Deutsch has uploaded a new change for review.

Change subject: tests: Add sizes page to mi_basic
......................................................................

tests: Add sizes page to mi_basic

Change-Id: I08b3e6634db3d4e0eff359f72c2ec270039332ee
Signed-off-by: Fabian Deutsch <fabiand at fedoraproject.org>
---
M tests/igor/tcs/uinput/basic_tui_installation.py
1 file changed, 7 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/ovirt-node refs/changes/21/8621/1

diff --git a/tests/igor/tcs/uinput/basic_tui_installation.py b/tests/igor/tcs/uinput/basic_tui_installation.py
index 34909c5..d2bf9a6 100644
--- a/tests/igor/tcs/uinput/basic_tui_installation.py
+++ b/tests/igor/tcs/uinput/basic_tui_installation.py
@@ -40,11 +40,15 @@
     # P. 4: Enter installation device selection
     (["\n"],                4, "installation of oVirt Node"),
 
-    # P. 5: Enter password dialog
-    (["\t\t\t\n"],          4, "Require a password"),
+    # P. 5: Enter sizes dialog
+    (["\t\t\t\n"],           4, "enter the sizes for"),
+
+    # P. 6: Enter password dialog
+    (["\t\t\t\t\t\t\n"],           4, "Require a password"),
+    # P. 6: Enter password
     (["ovirt\tovirt\t"],    2, "a weak password"),
 
-    # P. 6: Start installation, and give it at most 240 seconds to complete
+    # P. 7: Start installation, and give it at most 240 seconds to complete
     (["\t\t\n"],   wait_for_last_page, "Installation Finished"),
 ]
 


--
To view, visit http://gerrit.ovirt.org/8621
To unsubscribe, visit http://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I08b3e6634db3d4e0eff359f72c2ec270039332ee
Gerrit-PatchSet: 1
Gerrit-Project: ovirt-node
Gerrit-Branch: master
Gerrit-Owner: Fabian Deutsch <fabiand at fedoraproject.org>



More information about the node-patches mailing list